==> cc.fovea.cordova.openwith-1.0.1.tgz: package/hooks/npmInstall.js <==
// Copyright (c) 2017 DavidStrausz
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

const PLUGIN_ID = "cc.fovea.cordova.openwith";

module.exports = function (context) {
    var child_process = context.requireCordovaModule('child_process');
    var deferral = context.requireCordovaModule('q').defer();

    console.log('Installing "' + PLUGIN_ID + '" dependencies');
    child_process.exec('npm install --production', {cwd:__dirname}, function (error) {
        if (error !== null) {
            console.log('exec error: ' + error);
            deferral.reject('npm installation failed');
        }
        deferral.resolve();
    });

    return deferral.promise;
};

// vim: ts=4:sw=4:et

==> cc.fovea.cordova.openwith-2.1.0.tgz: package/hooks/npmInstall.js <==
// Copyright (c) 2017 DavidStrausz
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

const PLUGIN_ID = "cc.fovea.cordova.openwith";

module.exports = function (context) {
    var child_process = require('child_process');
    var deferral = require('q').defer();

    console.log('Installing "' + PLUGIN_ID + '" dependencies');
    child_process.exec('npm install --production', {cwd:__dirname}, function (error) {
        if (error !== null) {
            console.log('exec error: ' + error);
            deferral.reject('npm installation failed');
        }
        deferral.resolve();
    });

    return deferral.promise;
};

// vim: ts=4:sw=4:et
